summaryrefslogtreecommitdiff
path: root/include/ruby/impl/intern/select/win32.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/impl/intern/select/win32.h')
-rw-r--r--include/ruby/impl/intern/select/win32.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/include/ruby/impl/intern/select/win32.h b/include/ruby/impl/intern/select/win32.h
index 85289072cb..f45a733f59 100644
--- a/include/ruby/impl/intern/select/win32.h
+++ b/include/ruby/impl/intern/select/win32.h
@@ -1,5 +1,5 @@
-#ifndef RUBY3_INTERN_SELECT_WIN32_H /*-*-C++-*-vi:se ft=cpp:*/
-#define RUBY3_INTERN_SELECT_WIN32_H
+#ifndef RBIMPL_INTERN_SELECT_WIN32_H /*-*-C++-*-vi:se ft=cpp:*/
+#define RBIMPL_INTERN_SELECT_WIN32_H
/**
* @file
* @author Ruby developers <ruby-core@ruby-lang.org>
@@ -7,7 +7,7 @@
* Permission is hereby granted, to either redistribute and/or
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
* @warning Symbols prefixed with either `RUBY3` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file
* is also an implementation detail. Do not expect it to persist
@@ -37,7 +37,7 @@
#define rb_fd_max rb_fd_max
/** @endcond */
-RUBY3_SYMBOL_EXPORT_BEGIN()
+RBIMPL_SYMBOL_EXPORT_BEGIN()
struct timeval;
@@ -52,38 +52,38 @@ void rb_fd_set(int, rb_fdset_t *);
void rb_w32_fd_copy(rb_fdset_t *, const fd_set *, int);
void rb_w32_fd_dup(rb_fdset_t *dst, const rb_fdset_t *src);
-RUBY3_SYMBOL_EXPORT_END()
+RBIMPL_SYMBOL_EXPORT_END()
-RUBY3_ATTR_NONNULL(())
-RUBY3_ATTR_NOALIAS()
+RBIMPL_ATTR_NONNULL(())
+RBIMPL_ATTR_NOALIAS()
static inline void
rb_fd_zero(rb_fdset_t *f)
{
f->fdset->fd_count = 0;
}
-RUBY3_ATTR_NONNULL(())
+RBIMPL_ATTR_NONNULL(())
static inline void
rb_fd_clr(int n, rb_fdset_t *f)
{
rb_w32_fdclr(n, f->fdset);
}
-RUBY3_ATTR_NONNULL(())
+RBIMPL_ATTR_NONNULL(())
static inline int
rb_fd_isset(int n, rb_fdset_t *f)
{
return rb_w32_fdisset(n, f->fdset);
}
-RUBY3_ATTR_NONNULL(())
+RBIMPL_ATTR_NONNULL(())
static inline void
rb_fd_copy(rb_fdset_t *dst, const fd_set *src, int n)
{
rb_w32_fd_copy(dst, src, n);
}
-RUBY3_ATTR_NONNULL(())
+RBIMPL_ATTR_NONNULL(())
static inline void
rb_fd_dup(rb_fdset_t *dst, const rb_fdset_t *src)
{
@@ -101,8 +101,8 @@ rb_fd_select(int n, rb_fdset_t *rfds, rb_fdset_t *wfds, rb_fdset_t *efds, struct
timeout);
}
-RUBY3_ATTR_NONNULL(())
-RUBY3_ATTR_PURE()
+RBIMPL_ATTR_NONNULL(())
+RBIMPL_ATTR_PURE()
/* :TODO: can this function be __attribute__((returns_nonnull)) or not? */
static inline fd_set *
rb_fd_ptr(const rb_fdset_t *f)
@@ -110,15 +110,15 @@ rb_fd_ptr(const rb_fdset_t *f)
return f->fdset;
}
-RUBY3_ATTR_NONNULL(())
-RUBY3_ATTR_PURE()
+RBIMPL_ATTR_NONNULL(())
+RBIMPL_ATTR_PURE()
static inline int
rb_fd_max(const rb_fdset_t *f)
{
const fd_set *p = f->fdset;
- RUBY3_ASSERT_OR_ASSUME(p);
+ RBIMPL_ASSERT_OR_ASSUME(p);
return p->fd_count;
}
-#endif /* RUBY3_INTERN_SELECT_WIN32_H */
+#endif /* RBIMPL_INTERN_SELECT_WIN32_H */
@@ -7,7 +7,7 @@
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
- * @warning Symbols prefixed with either `RUBY3` or `ruby3` are
+ * @warning Symbols prefixed with either `RBIMPL` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file